@@ -779,9 +779,11 @@ def test_middleware_partial_receive_send(sentry_init, capture_events):
         },
         {
             "op": "middleware.starlette.receive",
-            "description": "_ASGIAdapter.send.<locals>.receive"
-            if STARLETTE_VERSION < (0, 21)
-            else "_TestClientTransport.handle_request.<locals>.receive",
+            "description": (
+                "_ASGIAdapter.send.<locals>.receive"
+                if STARLETTE_VERSION < (0, 21)
+                else "_TestClientTransport.handle_request.<locals>.receive"
+            ),
             "tags": {"starlette.middleware_name": "ServerErrorMiddleware"},
         },
         {
